@@ -155,7 +155,7 @@ class ControllerRedShift:
                                 )
             cur.execute(redshift_insert_query, record_to_insert)
             
-    def date_decomposition(self,transaction_date):
+    def date_descomposition(self,transaction_date):
         
         transaction_date = datetime.strptime(transaction_date, self.date_format).date()
         year = transaction_date.year
