@@ -29,31 +29,39 @@ MongoDB.get_con_collect(collection_name='fact')
 
 
 def get_info_by_transaction_uid(transaction_uid):
+
     MongoDB.get_con_collect(collection_name='analytic')
     
     responde_transaction = MongoDB.con_db.find_one({'_id': transaction_uid})
 
     if not responde_transaction:
         responde_transaction = MongoDB.con_db.find_one({"history-track.USER.transaction_uid": transaction_uid})
-
     
     if responde_transaction is None :
         return 
 
     reponse = dict()
     reponse['account_uid'] =responde_transaction['history-track'][0]['USER']['account_uid']
+
+    if not 'raw' in responde_transaction['history-track'][0]['USER']:
+        print("No raw")
+        return None
+    
+    if not 'amount' in responde_transaction['history-track'][0]['USER']['raw']:
+        print("responde_transaction: ", responde_transaction)
+        print("---------------------------______________________________-----------------")
+        return None
+
     reponse['amount'] =responde_transaction['history-track'][0]['USER']['raw']['amount']
     reponse['currency'] =responde_transaction['history-track'][0]['USER']['raw']['currency']
     reponse['bank_name'] =responde_transaction['history-track'][0]['USER']['raw']['account']['institution']['name']
     reponse['account_type'] =responde_transaction['history-track'][0]['USER']['raw']['account']['type']
     reponse['bank_type'] =responde_transaction['history-track'][0]['USER']['raw']['account']['institution']['type']
+    
     if 'message_type' in responde_transaction['history-track'][0]['CASE']:
         reponse['message_type'] =responde_transaction['history-track'][0]['CASE']['message_type']
-
-
-    print(reponse)
-
-    
+    else :
+        reponse['message_type'] = 'transaction-categorized'
 
     # ['raw']['account']['name']
     # ['raw']['account']['number']
@@ -251,7 +259,7 @@ front_date = today.strftime("%Y-%m-%d")
 print(today)
 print("front_date: " , front_date)
 
-s = Summary(front_date,num_days = 75)
+s = Summary(front_date,num_days = 250)
 r = s.agg_master()
 
 
@@ -338,26 +346,14 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
     if response is None :
         continue 
     
-    print(response)
+    print("response: ",response)
+    print("+++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
+    print("item: ", item)
     # Dict to necessary data
     transaction_dict = Transaction_().get()
     transaction_dict.update(item)
     
     transaction_dict.update(response)
-
-    
-    
-    
-    if not 'message_type' in response:
-        if transaction_dict['message_type_head'] is not None:
-            transaction_dict['message_type'] = transaction_dict['message_type_head'] 
-        elif transaction_dict['message_type_history']  is not None:
-            transaction_dict['message_type'] = transaction_dict['message_type_history'] 
-        elif transaction_dict['message_type_old']  is not None:
-            transaction_dict['message_type'] = transaction_dict['message_type_old']
-        else: 
-            transaction_dict['message_type'] = 'ingest'
-    
     
 
 
@@ -431,16 +427,17 @@ for idx ,item in enumerate(r.to_dict(orient='records')):
     
         RedShift.insert_dim_account(dict_values = account_dict)
     
-    print("****************************************\n")
-    print(account_dict)
-    print("****************************************\n")
-    print(user_dict)
-    print("****************************************\n")
+        print("****************************************\n")
+        print(account_dict)
+        print("****************************************\n")
+        print(user_dict)
+        print("****************************************\n")
+        
     print(transaction_dict)
     print("****************************************\n")
 
 
-    date_dict = RedShift.date_decomposition(str(item['created_at_head']).replace(" ","T").split(".")[0])
+    date_dict = RedShift.date_descomposition(str(response['collected_at']).replace(" ","T").split(".")[0])
     table_name = 'dim_dates'
     column_name = 'transaction_date'
 
