@@ -1,7 +1,7 @@
 
 
 from numpy import sum as sum_, array, floor
-from pandas import Series,concat,DataFrame
+from pandas import Series,concat,DataFrame, to_datetime
 from datetime import datetime,timedelta
 from klp_commons.controllers.controller_mongodb import ControllerMongoDB
 from klp_commons.controllers.controller_postgresdb import ControllerPostgresDB
@@ -220,15 +220,15 @@ class Summary:
 
     def trasform_datetime(self):
         
-        self.df_master['classification_date'] = pd.to_datetime(s.df_master.classified_at).dt.date
-        self.df_master['classification_time'] = pd.to_datetime(s.df_master.classified_at).dt.time
+        self.df_master['classification_date'] = to_datetime(s.df_master.classified_at).dt.date
+        self.df_master['classification_time'] = to_datetime(s.df_master.classified_at).dt.time
         
-        self.df_master['created_at_date'] = pd.to_datetime(s.df_master.classified_at).dt.date
-        self.df_master['created_at_time'] = pd.to_datetime(s.df_master.classified_at).dt.time
+        self.df_master['created_at_date'] = to_datetime(s.df_master.classified_at).dt.date
+        self.df_master['created_at_time'] = to_datetime(s.df_master.classified_at).dt.time
         
         
-        self.df_master['updated_at_date'] = pd.to_datetime(s.df_master.classified_at).dt.date
-        self.df_master['updated_at_time'] = pd.to_datetime(s.df_master.classified_at).dt.time     
+        self.df_master['updated_at_date'] = to_datetime(s.df_master.classified_at).dt.date
+        self.df_master['updated_at_time'] = to_datetime(s.df_master.classified_at).dt.time     
         
     def remove_conflicts(self):
         ids_list = self.df_master[self.df_master.created_at<self.from_date].id.values.tolist()
